<?php

namespace GopNext\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;

class OperatingBudgetParametersController {
    
    protected $service;
    protected $crudService;
    
    public function __construct($connection, $environment, $util, $service, $crudService){
        $this->connection   = $connection;
        $this->environment  = $environment;
        $this->util         = $util;
        $this->service      = $service;
        $this->crudService	= $crudService;
    }
    
    public function operationalItem(Request\DataSet $request, Response $response) {
        $conditions = [];
        $rows = $request->getDataSet()->getRows();
        try{
            $this->service->beginTransaction();
            $operationalItem = $this->crudService->getFilteredDataSet('operationalItem', $conditions)->getRows();
            if(count($operationalItem) == 0){
                $this->insertItems($rows);         
            }
            $data = [];
            $parametersBudgetOperation = $this->service->reciveParametersForBudgetOperation();
            if(count($parametersBudgetOperation) == 0){
                $params = [
                    "IDTIPOSIMULARESULTFAT" => $row["IDTIPOSIMULARESULTFAT"],
                    "IDUTILMESBASE" => $row["IDUTILMESBASE"],
                    "CDTIPOCUSTO" => $row["CDTIPOCUSTO"],
                    "CDINDICECON" => $row["CDINDICECON"],
                    "CDINDICEFAT" => $row["CDINDICEFAT"],
                    "IDORCDESPDIVERS" => $row["IDORCDESPDIVERS"],
                    "IDORCADESPMATRI" => $row["IDORCADESPMATRI"],
                    "IDORCDESPENTROP" => $row["IDORCDESPENTROP"],
                    "NRDIALIMITEORCA" => $row["NRDIALIMITEORCA"],
                    "IDPERORCAITEMDETAL" => $row["IDPERORCAITEMDETAL"],
                    "IDUTILVERSAOORCA" => $row["IDUTILVERSAOORCA"],
                    "IDAPROVORCACONC" => $row["IDAPROVORCACONC"],
                    "IDCALCFATUROP" => $row["IDCALCFATUROP"],
                    "NRDIAANTELABORCA" => $row["NRDIAANTELABORCA"],
                    "IDUTILORCAREALOC" => $row["IDUTILORCAREALOC"],
                    "IDCONSORCREALOC" => $row["IDCONSORCREALOC"],
                    "IDPERIODOORCA" => $row["IDPERIODOORCA"],
                    "IDREALINFORCA" => $row["IDREALINFORCA"],
                    "IDREALSUPORCA" => $row["IDREALSUPORCA"],
                    "NRDIAINIORCA" => $row["NRDIAINIORCA"],
                    "NRMESINIORCA" => $row["NRMESINIORCA"]
                ];
                $this->service->insertGeneral($params);
            }
            
            $this->service->commit();
            array_push($data, $operationalItem, $parametersBudgetOperation);
            $response->addDataSet(new DataSet("validateOperationalitemsSelect", $data));
            
        }catch(Exception $e) {
            $this->service->rollback();
            throw $e;
        }
    }

    public function insertItems($rows) {
        $this->service->beginTransaction();
        $idCheck = 'S';
        try{
            foreach($rows as $row) {
               switch ($row["value"]) {
                    case 0:
                        $idTipoOrca = "FATURAMENTO";
                        break;
                    case 1:
                        $idTipoOrca = "IMPOSTO";
                        break;
                    case 2:
                        $idTipoOrca = "CONSUMO";
                        break;
                    case 3:
                        $idTipoOrca = "MAOOBRA";
                        break;
                    case 4:
                        $idTipoOrca = "TAXAADM";
                        break;
                    case 5:
                        $idTipoOrca = "DESPMATRIZ";
                        break;
                    case 6:
                        $idTipoOrca = "DESPDIVERSA";
                        break;
                    case 7:
                        $idTipoOrca = "DESPENTRADA";
                        break;
                    case 8:
                        $idTipoOrca = "IMPOSTOARECUPERAR";
                        break;
                    case 9:
                        $idTipoOrca = "IMPOSTOSOBLUCRO";
                        break;
                    case 10:
                        $idTipoOrca = "INVESTIMENTO";
                        break;
                    case 11:
                        $idTipoOrca = "DEPRECIACAO";
                        break;
                }
                $params = [
                    "NRITEMOPERACIONAL"   => $row["value"],
                    "IDCHECK"             => $idCheck,
                    "IDTIPOORCAOP"        => $idTipoOrca
                ];
                $this->service->insertOperationalItem($params); 
            }
            $this->service->commit();
        }catch(Exception $e) {
            $this->service->rollback();
            throw $e;
        }   
    }
    
    public function saveOpBudgetParamsOperation(Request\Row $request, Response $response) {
        $row = $request->getRow();
        try {
            $this->service->beginTransaction();
            
            $params = [
                "IDTIPOSIMULARESULTFAT" => $row["IDTIPOSIMULARESULTFAT"],
                "IDUTILMESBASE" => $row["IDUTILMESBASE"],
                "CDTIPOCUSTO" => $row["CDTIPOCUSTO"],
                "CDINDICECON" => $row["CDINDICECON"],
                "CDINDICEFAT" => $row["CDINDICEFAT"],
                "IDORCDESPDIVERS" => $row["IDORCDESPDIVERS"],
                "IDORCADESPMATRI" => $row["IDORCADESPMATRI"],
                "IDORCDESPENTROP" => $row["IDORCDESPENTROP"],
                "NRDIALIMITEORCA" => $row["NRDIALIMITEORCA"],
                "IDPERORCAITEMDETAL" => $row["IDPERORCAITEMDETAL"],
                "IDUTILVERSAOORCA" => $row["IDUTILVERSAOORCA"],
                "IDAPROVORCACONC" => $row["IDAPROVORCACONC"],
                "IDCALCFATUROP" => $row["IDCALCFATUROP"],
                "NRDIAANTELABORCA" => $row["NRDIAANTELABORCA"],
                "IDUTILORCAREALOC" => $row["IDUTILORCAREALOC"],
                "IDCONSORCREALOC" => $row["IDCONSORCREALOC"],
                "IDPERIODOORCA" => $row["IDPERIODOORCA"],
                "IDREALINFORCA" => $row["IDREALINFORCA"],
                "IDREALSUPORCA" => $row["IDREALSUPORCA"],
                "NRDIAINIORCA" => $row["NRDIAINIORCA"],
                "NRMESINIORCA" => $row["NRMESINIORCA"]
            ];
            var_dump($params);
            $this->service->updateOpBudgetParamsOperation($params);

            $this->service->commit();
        } catch (\Exception $ex) {
            $this->service->rollback();
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function populateOpBudgetParamsGrid(Request\Filter $request, Response $response) {
        $params = ['CDOPERADOR' ];
        $conditions = $this->util->prepareConditions($params);
        array_push($conditions, array(
                "columnName" => "IDCNTRRESC",
                "operator"   => '=',
                "value"      => 'T'
            ));
        $data = $this->crudService->getFilteredDataSet('filioper', $conditions)->getRows();
    	$response->addDataSet(new DataSet("populateOpBudgetParamsGrid", $data));
    }
    
    public function populateOpBudgetParamsUnit(Request\Row $request, Response $response) {
        $row = $request->getRow();
        $params = ['NRORG'];
        $conditions = $this->util->prepareConditions($params);
        array_push($conditions, array(
                "columnName" => "CDFILIAL",
                "operator" => "=",
                "value" =>  $row["CDFILIAL"]
        ));
        $data = $this->crudService->getFilteredDataSet('operatingUnit', $conditions)->getRows();
    	$response->addDataSet(new DataSet("operatingUnit", $data));
    }
    
    public function saveOpBudgetParamsUnit(Request\Row $request, Response $response) {
        $row = $request->getRow();
        try {
            $this->service->beginTransaction();
    
            $params = [
                "NRMESREAJCONTR" => $row["NRMESREAJCONTR"],
                "VRPEORCBLOQFIL" => strval($row["VRPEORCBLOQFIL"]),
                "VRPEORCALERTFIL" => strval($row["VRPEORCALERTFIL"]),
                "IDCALCOMESTORC" => $row["IDCALCOMESTORC"],
                "IDCONSAPENCARDAPROV" => $row["IDCONSAPENCARDAPROV"],
                "NRDIAINIORCAGOP" => strval($row["NRDIAINIORCAGOP"]),
                "IDUTILPERCFILGOP" => $row["IDUTILPERCFILGOP"],
                "CDFILIAL" => $row["CDFILIAL"]
            ];
            $this->service->updateOpBudgetParamsUnit($params);

            $this->service->commit();
        } catch (\Exception $ex) {
            $this->service->rollback();
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function saveOpBudgetParamsItem(Request\Row $request, Response $response) {
        $row = $request->getRow();
        try {
            $stNrIemOperacional = '_' . implode('_', $row['NRITEMOPERACIONAL']) . '_';
            $this->service->beginTransaction();
    

                $params = array(
                    "NRITEMOPERACIONAL" => $stNrIemOperacional
                );
                $this->service->updateOpBudgetParamsItem($params);
            
            
            $this->service->commit();
            
        } catch(Exception $ex) {
            $this->service->rollback();
            throw $ex;
        }
    }
}